==> acl2_7.2dfsg-3.debian.tar.xz: debian/patches/add-upstream-certificate-relocation-patch-to-other-events.lisp <==
Description: <short summary of the patch>
 TODO: Put a short summary on the line above and replace this paragraph
 with a longer explanation of this change. Complete the meta-information
 with other relevant fields (see below for details). To make it easier, the
 information below has been extracted from the changelog. Adjust it or drop
 it.
 .
 acl2 (6.2-8) unstable; urgency=low
 .
   * Allow certification failures for 1) dlopen machines, as we cannot
     control the surpassed 1024 maximum dlopen limit, and 2) machines with
     an insufficient hard limit on data segment size (e.g. kfreebsd-i386, or any
     machine which cannot brk 1Gb).
   * add build-dep on texinfo
   * add upstream certificate relocation patch to other-events.lisp
Author: Camm Maguire <camm@debian.org>

---
The information above should follow the Patch Tagging Guidelines, please
checkout http://dep.debian.net/deps/dep3/ to learn about the format. Here
are templates for supplementary fields that you might want to add:

Origin: <vendor|upstream|other>, <url of original patch>
Bug: <url in upstream bugtracker>
Bug-Debian: http://bugs.debian.org/<bugnumber>
Bug-Ubuntu: https://launchpad.net/bugs/<bugnumber>
Forwarded: <no|not-needed|url proving that it has been forwarded>
Reviewed-By: <name and email of someone who approved the patch>
Last-Update: <YYYY-MM-DD>

--- acl2-6.2.orig/other-events.lisp
+++ acl2-6.2/other-events.lisp
@@ -12970,7 +12970,9 @@
    certification-file
    (replace-string-prefix-in-tree
     post-alist3 old-dir (length old-dir) new-dir)
-   expansion-alist pcert-info cert-op ctx state))
+   (replace-string-prefix-in-tree
+    expansion-alist old-dir (length old-dir) new-dir)
+   pcert-info cert-op ctx state))
 
 (defun make-certificate-file (file portcullis post-alist1 post-alist2
                                    expansion-alist pcert-info

==> acl2_8.6+dfsg-3.debian.tar.xz: debian/patches/add-upstream-certificate-relocation-patch-to-other-events.lisp <==
Description: add-upstream-certificate-relocation-patch-to-other-events.lisp
Forwarded: not-needed
 TODO: Put a short summary on the line above and replace this paragraph
 with a longer explanation of this change. Complete the meta-information
 with other relevant fields (see below for details). To make it easier, the
 information below has been extracted from the changelog. Adjust it or drop
 it.
 .
 acl2 (6.2-8) unstable; urgency=low
 .
   * Allow certification failures for 1) dlopen machines, as we cannot
     control the surpassed 1024 maximum dlopen limit, and 2) machines with
     an insufficient hard limit on data segment size (e.g. kfreebsd-i386, or any
     machine which cannot brk 1Gb).
   * add build-dep on texinfo
   * add upstream certificate relocation patch to other-events.lisp
Author: Camm Maguire <camm@debian.org>

---
The information above should follow the Patch Tagging Guidelines, please
checkout http://dep.debian.net/deps/dep3/ to learn about the format. Here
are templates for supplementary fields that you might want to add:

Origin: <vendor|upstream|other>, <url of original patch>
Bug: <url in upstream bugtracker>
Bug-Debian: http://bugs.debian.org/<bugnumber>
Bug-Ubuntu: https://launchpad.net/bugs/<bugnumber>
Forwarded: <no|not-needed|url proving that it has been forwarded>
Reviewed-By: <name and email of someone who approved the patch>
Last-Update: <YYYY-MM-DD>

--- acl2-6.2.orig/other-events.lisp
+++ acl2-6.2/other-events.lisp
@@ -12970,7 +12970,9 @@
    certification-file
    (replace-string-prefix-in-tree
     post-alist3 old-dir (length old-dir) new-dir)
-   expansion-alist pcert-info cert-op ctx state))
+   (replace-string-prefix-in-tree
+    expansion-alist old-dir (length old-dir) new-dir)
+   pcert-info cert-op ctx state))
 
 (defun make-certificate-file (file portcullis post-alist1 post-alist2
                                    expansion-alist pcert-info
